<?php

namespace App\Models;

use CodeIgniter\Model;

class EmployeeModel extends Model
{
    protected $table = 'employee_details'; 

    protected $primaryKey = 'id'; 

    protected $allowedFields = [
        'employee_id',
        'profile_img',
        'first_name', 
        'last_name', 
        'email', 
        'department', 
        'title', 
        'source_of_hire', 
        'date_of_joining', 
        'employee_status', 
        'work_phone', 
        'employee_type', 
        'role', 
        'pan_number', 
        'date_of_birth', 
        'marital_status', 
        'emp_address', 
        'residential_address', 
        'job_description', 
        'gender', 
        'about_me',
        'previous_company_name',
        'job_title',
        'from_date',
        'to_date',
        'job_description_work_exp',
        'college_name',
        'diploma_degree',
        'field_of_study',
        'date_of_completion',
        'additional_notes',
        'interests',
        'aggregate',
        'dependent_name',
        'relationship',
        'dependent_date_of_birth',
    ];


    protected $useTimestamps = true; 
    protected $createdField = 'created_at'; 

    public function getEmployeeList()
    {
        return $this->findAll();
    }


    public function findEmployeeById($id)
{
    
    $query = $this->where('id', $id)->get();

    
    if ($query->getNumRows() > 0) {
        
        return $query->getRow();
    } else {
        
        return null;
    }
}


    public function getWorkData($employeeId)
    {
        return $this->db->table('employee_work_experience')
                        ->where('employee_id', $employeeId)
                        ->get()
                        ->getResultArray();
    }

    public function getEducation($employeeId)
    {
        return $this->db->table('employee_education')
                        ->where('employee_id', $employeeId)
                        ->get()
                        ->getResultArray();
    }

    public function getDependents($employeeId)
    {
        return $this->db->table('employee_dependents')
                        ->where('employee_id', $employeeId)
                        ->get()
                        ->getResultArray();
    }

    // public function updateEmployee($employee_id, $data)
    // {
    //     $this->where('employee_id', $employee_id)->set($data)->update();
    // }
    
    public function updateEmployee($employee_id, $data)
    {
        // print_r($employee_id);die();
        $this->where('id', $employee_id)->set($data)->update();
    }
    



    public function getWorkById($id)
    {
        $builder = $this->db->table('employee_work_experience');
        $builder->where('id', $id);
        $query = $builder->get();
        return $query->getRowArray(); 
    }


    public function updateWork($data)
    {
        $builder = $this->db->table('employee_work_experience');
        $builder->where('id', $data['id']);
        return $builder->update($data);
    }

  
    public function insertWork($data)
    {
        $builder = $this->db->table('employee_work_experience');
        // $builder->where('employee_id',$data['employee_id']);
        return $builder->insert($data);
    }
    
    public function insertEmployeeAndGetID(array $data)
    {
        $this->insert($data);
        return $this->insertID();
    }
    public function deleteWork($id)
    {
        $db = \Config\Database::connect();
        $builder = $db->table('employee_work_experience');
        return $builder->delete(['id' => $id]);
    }



    public function getEducationById($id)
    {
        $builder = $this->db->table('employee_education');
        $builder->where('id', $id);
        $query = $builder->get();
        return $query->getRowArray(); 
    }

  
    public function updateEducation($data)
    {
        $builder = $this->db->table('employee_education');
        $builder->where('id', $data['id']);
        return $builder->update($data);
    }

   
    public function insertEducation($data)
    {
        $builder = $this->db->table('employee_education');
        // $builder->where('employee_id',$data['employee_id']);
        return $builder->insert($data);
    }


    public function getDependentById($id)
    {
        $builder = $this->db->table('employee_dependents');
        $builder->where('id', $id);
        $query = $builder->get();
        return $query->getRowArray(); 
    }

 
    public function updateDependent($data)
    {
        $builder = $this->db->table('employee_dependents');
        $builder->where('id', $data['id']);
        return $builder->update($data);
    }

    
    public function insertDependent($data)
    {
        $builder = $this->db->table('employee_dependents');
        // $builder->where('id',$data['id']);
        return $builder->insert($data);
    }
}